<?php

namespace Registro\Registro\Policies;

use Litepie\User\Contracts\UserPolicy;
use Registro\Registro\Models\Visitante;

class VisitantePolicy
{

    /**
     * Determine if the given user can view the visitante.
     *
     * @param UserPolicy $user
     * @param Visitante $visitante
     *
     * @return bool
     */
    public function view(UserPolicy $user, Visitante $visitante)
    {
        if ($user->canDo('registro.visitante.view') && $user->isAdmin()) {
            return true;
        }

        return $visitante->user_id == user_id() && $visitante->user_type == user_type();
    }

    /**
     * Determine if the given user can create a visitante.
     *
     * @param UserPolicy $user
     * @param Visitante $visitante
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('registro.visitante.create');
    }

    /**
     * Determine if the given user can update the given visitante.
     *
     * @param UserPolicy $user
     * @param Visitante $visitante
     *
     * @return bool
     */
    public function update(UserPolicy $user, Visitante $visitante)
    {
        if ($user->canDo('registro.visitante.edit') && $user->isAdmin()) {
            return true;
        }

        return $visitante->user_id == user_id() && $visitante->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given visitante.
     *
     * @param UserPolicy $user
     * @param Visitante $visitante
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Visitante $visitante)
    {
        return $visitante->user_id == user_id() && $visitante->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given visitante.
     *
     * @param UserPolicy $user
     * @param Visitante $visitante
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Visitante $visitante)
    {
        if ($user->canDo('registro.visitante.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given visitante.
     *
     * @param UserPolicy $user
     * @param Visitante $visitante
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Visitante $visitante)
    {
        if ($user->canDo('registro.visitante.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
