<?php

namespace Registro\Registro\Providers;

use Illuminate\Support\ServiceProvider;

class RegistroServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'registro');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'registro');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('registro.registro', function ($app) {
            return $this->app->make('Registro\Registro\Registro');
        });

                // Bind Visitante to repository
        $this->app->bind(
            'Registro\Registro\Interfaces\VisitanteRepositoryInterface',
            \Registro\Registro\Repositories\Eloquent\VisitanteRepository::class
        );

        $this->app->register(\Registro\Registro\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Registro\Registro\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['registro.registro'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('registro/registro.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/registro')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/registro')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
